@@ -56,7 +56,7 @@ class Client:
             token = self.get_token()
         if not isinstance(_from, datetime):
             raise Exception('_from must be of type date.')
-        r = requests.get('%sv2/charts/data/%s/%s?from=%s&to=%s' % (Client.BASE_URL, symbol, resolution, _from.strftime('%Y%m%d%H%M'), _to if _to else ''), headers = {'Access-Token': token})
+        r = requests.get('%sv2/charts/data/%s/%s?from=%s&to=%s' % (Client.BASE_URL, symbol, resolution, _from.strftime('%Y%m%d%H%M'), _to.strftime('%Y%m%d%H%M') if _to else ''), headers = {'Access-Token': token})
         return r.json()
 
     def get_options_positions(self, token = None):
